@@ -92,7 +92,7 @@ void MainWindow::showExpanded()
 void MainWindow::on_capital_clicked()
 {
     QProcess process;
-    process.start("sh /opt/serviziopubblico/script/capital.sh");
+    process.start("sh /opt/serviziopubblico/script/radicale.sh");
     process.waitForFinished();
 }
 
