@@ -80,6 +80,10 @@ private slots:
 
     void on_stream15_clicked();
 
+    void on_down16_clicked();
+
+    void on_stream16_clicked();
+
 private:
     Ui::PuntateMain *ui;
 };
